pub trait MonoidValue: SemigroupValue + HasZero { }Expand description
A type with an associative addition and a zero.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T> MonoidValue for Twhere
T: SemigroupValue + HasZero,
Default implementation for all types that have an addition and a zero.