PartialOrder

Trait PartialOrder 

pub trait PartialOrder: Eq {
    // Required method
    fn less_equal(&self, other: &Self) -> bool;

    // Provided method
    fn less_than(&self, other: &Self) -> bool { ... }
}
A type that is partially ordered.

This trait is distinct from Rust’s PartialOrd trait to allow for a different ordering. In particular, PartialOrder compares multidimensional Timestamp representations for DBSP logical time, and PartialOrd compares them for other purposes such as sorting.

Required Methods

fn less_equal(&self, other: &Self) -> bool

Returns true if one element is less than or equal to the other

Provided Methods

fn less_than(&self, other: &Self) -> bool

Returns true if one element is strictly less than the other

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PartialOrder for ()

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for Duration

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for i8

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for i16

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for i32

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for i64

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for i128

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for isize

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for u8

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for u16

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for u32

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for u64

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for u128

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Source

impl PartialOrder for usize

Source

fn less_than(&self, other: &Self) -> bool

Source

fn less_equal(&self, other: &Self) -> bool

Implementors

Source

impl PartialOrder for UnitTimestamp

Source

impl<'a, T> PartialOrder for AntichainRef<'a, T>
where T: PartialOrder + 'a,

Source

impl<T> PartialOrder for Antichain<T>
where T: PartialOrder,

Source

impl<TOuter: PartialOrder, TInner: PartialOrder> PartialOrder for Product<TOuter, TInner>