Module circuit

Module circuit 

Synchronous circuits over streams.

A circuit consists of operators connected by streams. At every clock cycle, each operator consumes a single value from each of its input streams and emits a single value to the output stream (except that nested circuits can execute multiple operations for each outer clock tick).

Use RootCircuit::build to create and populate an circuit that executes in the calling thread, or Runtime::init_circuit to create a multi-circuit, multi-worker threaded runtime. These functions return a CircuitHandle or DBSPHandle, respectively, that control the circuits’ execution, plus, when used in the recommended way, additional input handles for feeding data into the circuits and output handles for obtaining their output.

Re-exports

pub use circuit_builder::ChildCircuit;
pub use circuit_builder::Circuit;
pub use circuit_builder::CircuitHandle;
pub use circuit_builder::ExportId;
pub use circuit_builder::ExportStream;
pub use circuit_builder::FeedbackConnector;
pub use circuit_builder::GlobalNodeId;
pub use circuit_builder::NestedCircuit;
pub use circuit_builder::NodeId;
pub use circuit_builder::OwnershipPreference;
pub use circuit_builder::RootCircuit;
pub use circuit_builder::Scope;
pub use circuit_builder::Stream;
pub use circuit_builder::WithClock;
pub use schedule::Error as SchedulerError;

Modules

cache
Circuit cache.
checkpointer
Logic to manage persistent checkpoints for a circuit.
circuit_builder
API to construct circuits.
metadata
metrics
Storage metrics.
operator_traits
Common traits for DBSP operators.
schedule
The scheduling framework controls the execution of a circuit at runtime.
tokio
trace
Definitions related to tracing the execution of a circuit.

Structs

CheckpointCommitter
Committer for a checkpoint.
CircuitConfig
A config for instantiating a multithreaded/multihost runtime to execute circuits.
CircuitStorageConfig
Configuration for storage in a Runtime-hosted circuit.
DBSPHandle
A handle to control the execution of a circuit in a multithreaded runtime.
DevTweaks
Host
A host for some workers in the Layout for a multi-host DBSP circuit.
LocalStoreMarker
Runtime
A multithreaded runtime that hosts N circuits running in parallel worker threads. Typically, all N circuits are identical, but this is not required or enforced.
RuntimeHandle
Handle returned by Runtime::run.
StorageConfig
Configuration for persistent storage in a PipelineConfig.
StorageOptions
Storage configuration for a pipeline.
WeakRuntime
A weak reference to a Runtime.

Enums

Layout
How a DBSP circuit is laid out across one or more machines.
LayoutError
Mode
DBSP circuit execution mode.
RuntimeError
StorageCacheConfig
How to cache access to storage within a Feldera pipeline.

Functions

adaptive_joins_enabled
balancer_balance_tax
balancer_key_distribution_refresh_threshold
balancer_min_absolute_improvement_threshold
balancer_min_relative_improvement_threshold
splitter_output_chunk_size
Returns the chunk size for splitter operators, in records.

Type Aliases

LocalStore
Local data store shared by all workers in a runtime.