dbsp::circuit::circuit_builder

Struct ExportStream

pub struct ExportStream<C, D>
where C: Circuit,
{ pub local: Stream<C, D>, pub export: Stream<C::Parent, D>, }
Stream whose final value is exported to the parent circuit.

The struct bundles a pair of streams emitted by a StrictOperator: a local stream inside operator’s local circuit and an export stream available to the parent of the local circuit. The export stream contains the final value computed by the operator before clock_end.

Fields

local: Stream<C, D>export: Stream<C::Parent, D>