pub enum Layout {
Solo {
n_workers: usize,
},
Multihost {
hosts: Vec<Host>,
local_host_idx: usize,
},
}Expand description
How a DBSP circuit is laid out across one or more machines.
Variants
Implementations
Sourceimpl Layout
impl Layout
Sourcepub fn new_solo(n_workers: usize) -> Layout
pub fn new_solo(n_workers: usize) -> Layout
Returns a new solo layout with n_workers worker threads.
Sourcepub fn new_multihost(
params: &[(SocketAddr, usize)],
local_address: SocketAddr,
) -> Result<Layout, LayoutError>
pub fn new_multihost( params: &[(SocketAddr, usize)], local_address: SocketAddr, ) -> Result<Layout, LayoutError>
Returns a new multihost layout with as many hosts as specified in
params. Each tuple in params specifies a host’s unique network
address and the number of workers to run on that host. local_address
must be one of the addresses in params.
To execute such a multihost circuit, one must create a Runtime for it
on every host in params, passing the same params in each case. Each
host must pass its own local_address. The Runtime on each host
listens on its own address and connects to all the other addresses.
Sourcepub fn local_workers(&self) -> Range<usize>
pub fn local_workers(&self) -> Range<usize>
Returns the range of IDs for the workers on the local machine.
Sourcepub fn other_hosts(&self) -> impl Iterator<Item = &Host>
pub fn other_hosts(&self) -> impl Iterator<Item = &Host>
Returns an iterator over Hosts in this layout other than this one. If
this is a single-host layout, this will be an empty iterator.
Sourcepub fn local_address(&self) -> Option<SocketAddr>
pub fn local_address(&self) -> Option<SocketAddr>
Returns the network address for the current machine, or None if this
is a solo layout.
pub fn is_multihost(&self) -> bool
pub fn is_solo(&self) -> bool