SourceOperator

Trait SourceOperator 

pub trait SourceOperator<O>: Operator {
    // Required method
    async fn eval(&mut self) -> O;
}
A source operator that injects data from the outside world or from the parent circuit into the local circuit. Consumes no input streams and emits a single output stream.

Required Methods

async fn eval(&mut self) -> O

Yield the next value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<IT, OT, F> SourceOperator<OT> for Input<IT, OT, F>
where IT: Clone + Debug + 'static, OT: 'static, F: Fn(IT) -> OT + 'static,

Source

impl<O, IF, T, L, D> SourceOperator<O> for ExchangeReceiver<IF, T, L, D>
where O: NumEntries + 'static, T: Clone + Debug + Send + 'static, IF: Fn() -> O + 'static, L: Fn(&mut O, T) + 'static, D: Fn(AlignedVec) -> T + Send + Sync + 'static,

Source

impl<R, T> SourceOperator<TypedBatch<T, (), i64, FallbackWSet<dyn Data, dyn WeightTyped<Type = i64>>>> for CsvSource<R, T>
where T: DBData + for<'de> Deserialize<'de> + 'static, R: Read + 'static,

Source

impl<T, F> SourceOperator<T> for Generator<T, F>
where F: FnMut() -> T + 'static, T: 'static,

Source

impl<T, F> SourceOperator<T> for TransactionGenerator<T, F>
where F: FnMut(bool) -> T + 'static, T: 'static,

Source

impl<T> SourceOperator<T> for ConstantGenerator<T>
where T: Data + 'static + Clone + Default,

Source

impl<T> SourceOperator<T> for GeneratorNested<T>
where T: Data,