pub enum Error {
OwnershipConflict {
origin: GlobalNodeId,
consumers: Vec<GlobalNodeId>,
},
CyclicCircuit {
node_id: GlobalNodeId,
},
CommitWithoutTransaction,
StepWithoutTransaction,
Killed,
TokioError {
error: String,
},
ReplayInfoConflict {
error: String,
},
}Expand description
Scheduler errors.
Variants
OwnershipConflict
origin node has more than one strong successors who insist on
consuming its output by value
(OwnershipPreference::STRONGLY_PREFER_OWNED or higher).
CyclicCircuit
Ownership constraints introduce a cycle in the circuit graph.
Fields

node_id: GlobalNodeIdCommitWithoutTransaction
StepWithoutTransaction
Killed
Execution of the circuit interrupted by the user (via
RuntimeHandle::kill).
TokioError
ReplayInfoConflict
Replay info conflict.
All workers should enter the replay mode with identical sets of replay and backfill nodes. If this is not the case, this indicates a bug or a corrupted checkpoint.