pub struct CircuitConfig {
pub layout: Layout,
pub max_rss_bytes: Option<u64>,
pub pin_cpus: Vec<usize>,
pub mode: Mode,
pub step_size: StepSize,
pub storage: Option<CircuitStorageConfig>,
pub dev_tweaks: DevTweaks,
pub exchange_listener: Option<TcpListener>,
}Expand description
A config for instantiating a multithreaded/multihost runtime to execute circuits.
As opposed to RuntimeConfig, this struct stores state about which hosts
run the circuit and where they store data, e.g., state typically not
tunable/exposed by the user.
Fields
layout: LayoutHow the circuit is laid out across one or multiple machines.
max_rss_bytes: Option<u64>The maximum amount of memory, in bytes, that the process is allowed to use. Used to calculate the memory pressure level.
pin_cpus: Vec<usize>Optionally, CPU numbers for pinning the worker threads.
mode: Modestep_size: StepSizeWhether the circuit can use microsteps.
storage: Option<CircuitStorageConfig>Storage configuration. If present, then storage is enabled.
dev_tweaks: DevTweaksParsed from RuntimeConfig for use by the circuit.
exchange_listener: Option<TcpListener>Optionally, the TCP socket on which to listen for exchange. This is
relevant only if layout is multihost. If it is provided, then the
socket must be listening on the port indicated for this host in
layout.
Implementations
Sourceimpl CircuitConfig
impl CircuitConfig
pub fn with_workers(n: usize) -> Self
pub fn with_max_rss_bytes(self, max_rss: Option<u64>) -> Self
pub fn with_mode(self, mode: Mode) -> Self
pub fn with_step_size(self, step_size: StepSize) -> Self
pub fn with_pin_cpus(self, pin_cpus: Vec<usize>) -> Self
pub fn with_storage(self, storage: Option<CircuitStorageConfig>) -> Self
pub fn with_dev_tweaks(self, dev_tweaks: DevTweaks) -> Self
pub fn with_streaming_exchange(self, enabled: bool) -> Self
pub fn with_splitter_chunk_size_records(self, records: u64) -> Self
pub fn with_buffer_cache_strategy(self, strategy: BufferCacheStrategy) -> Self
pub fn with_buffer_max_buckets(self, max_buckets: Option<usize>) -> Self
pub fn with_buffer_cache_allocation_strategy( self, strategy: BufferCacheAllocationStrategy, ) -> Self
pub fn with_balancer_min_relative_improvement_threshold( self, threshold: f64, ) -> Self
pub fn with_balancer_min_absolute_improvement_threshold( self, threshold: u64, ) -> Self
pub fn with_balancer_balance_tax(self, tax: f64) -> Self
pub fn with_exchange_listener(self, exchange_listener: TcpListener) -> Self