pub struct CircuitStorageConfig {
pub config: StorageConfig,
pub options: StorageOptions,
pub backend: Arc<dyn StorageBackend>,
pub init_checkpoint: Option<Uuid>,
}Expand description
Configuration for storage in a Runtime-hosted circuit.
Fields
config: StorageConfigRunner configuration.
options: StorageOptionsUser options.
backend: Arc<dyn StorageBackend>Storage backend.
Presumably opened according to config and options.
init_checkpoint: Option<Uuid>The initial checkpoint to start the circuit from, or None to start
fresh from a new circuit.
Implementations
Sourceimpl CircuitStorageConfig
impl CircuitStorageConfig
Sourcepub fn for_config(
config: StorageConfig,
options: StorageOptions,
) -> Result<Self, StorageError>
pub fn for_config( config: StorageConfig, options: StorageOptions, ) -> Result<Self, StorageError>
Opens a backend with config and options and returns a
CircuitStorageConfig with that backend.
pub fn with_init_checkpoint(self, init_checkpoint: Option<Uuid>) -> Self