pub struct Host {
pub address: SocketAddr,
pub workers: Range<usize>,
/* private fields */
}Expand description
A host for some workers in the Layout for a multi-host DBSP circuit.
Fields
address: SocketAddrThe IP address and TCP port on which the host listens and to which the other hosts connect.
workers: Range<usize>The worker thread IDs implemented on this host. Worker thread IDs start
with 0 in the first host and increase sequentially from there. A host
has workers.len() workers.