pub struct StorageConfig {
pub path: String,
pub cache: StorageCacheConfig,
}Expand description
Configuration for persistent storage in a PipelineConfig.
Fields
path: StringA directory to keep pipeline state, as a path on the filesystem of the machine or container where the pipeline will run.
When storage is enabled, this directory stores the data for StorageBackendConfig::Default.
When fault tolerance is enabled, this directory stores checkpoints and the log.
cache: StorageCacheConfigHow to cache access to storage in this pipeline.
Implementations