ClonableTrait

Trait ClonableTrait 

pub trait ClonableTrait: Clonable + DowncastTrait {
    // Provided methods
    fn clone_to(&self, dst: &mut Self) { ... }
    fn move_to(&mut self, dst: &mut Self) { ... }
}
Trait for trait objects whose concrete type can be cloned and moved.

Provided Methods

fn clone_to(&self, dst: &mut Self)

Clone self into dst.

fn move_to(&mut self, dst: &mut Self)

Move the contents of self into dst, replacing the contents of self with Self::default().

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Trait> ClonableTrait for Trait
where Trait: Clonable + DowncastTrait + ?Sized,