Data

Trait Data 

pub trait Data:
    Comparable
    + Clonable
    + SerializeDyn
    + DeserializableDyn
    + Send
    + Sync
    + Debug
    + AsAny
    + SizeOf
    + SupportsRoaring {
    // Required methods
    fn default_hash(&self) -> u64;
    fn dyn_hash(&self, hasher: &mut dyn Hasher);
    fn as_data(&self) -> &dyn Data;
    fn as_data_mut(&mut self) -> &mut dyn Data;
}
Defines the minimal set of operations that must be supported by all data types stored in DBSP batches.

This trait is object safe and can be invoked via dynamic dispatch.

Required Methods

fn default_hash(&self) -> u64

Compute a hash of the object using default hasher and seed.

fn dyn_hash(&self, hasher: &mut dyn Hasher)

fn as_data(&self) -> &dyn Data

Cast any type that implements this trait to &dyn Data.

This method will not be needed once trait downcasting has been stabilized.

fn as_data_mut(&mut self) -> &mut dyn Data

Cast any type that implements this trait to &mut dyn Data.

This method will not be needed once trait downcasting has been stabilized.