Pairs

Trait Pairs 

pub trait Pairs<T1: DataTrait + ?Sized, T2: DataTrait + ?Sized>: Vector<DynPair<T1, T2>> {
    // Required methods
    fn sort_by_key(&mut self);
    fn dedup_by_key_keep_last(&mut self);
    fn push_refs(&mut self, item: (&T1, &T2));
    fn as_pairs(&self) -> &DynPairs<T1, T2>;
    fn as_pairs_mut(&mut self) -> &mut DynPairs<T1, T2>;
}
A dynamically typed interface to LeanVec<Tup2<_,_>>

Required Methods

fn sort_by_key(&mut self)

Sort self by key.

fn dedup_by_key_keep_last(&mut self)

Removes all but the last of consecutive elements in the vector for each key.

fn push_refs(&mut self, item: (&T1, &T2))

Push a new element; clone its first and second components from item.

fn as_pairs(&self) -> &DynPairs<T1, T2>

Cast any trait object that implements this trait to &DynPairs.

This method will not be needed once trait downcasting has been stabilized.

fn as_pairs_mut(&mut self) -> &mut DynPairs<T1, T2>

Cast any trait object that implements this trait to &mut DynPairs.

This method will not be needed once trait downcasting has been stabilized.