Set

Trait Set 

pub trait Set<T: DataTrait + ?Sized>: Data {
    // Required methods
    fn len(&self) -> usize;
    fn clear(&mut self);
    fn insert_val(&mut self, val: &mut T);
    fn insert_ref(&mut self, val: &T);
    fn dyn_iter<'a>(&'a self) -> Box<dyn Iterator<Item = &'a T> + 'a>;
    fn as_set(&self) -> &DynSet<T>;
    fn as_set_mut(&mut self) -> &mut DynSet<T>;

    // Provided method
    fn is_empty(&self) -> bool { ... }
}
A dynamically typed interface to BTreeSet.

Required Methods

fn len(&self) -> usize

Return the number of elements in self.

fn clear(&mut self)

Clear the set, removing all elements.

fn insert_val(&mut self, val: &mut T)

Add a value to the set without cloning.

Sets val to the default value.

fn insert_ref(&mut self, val: &T)

Add a value to the set, cloning it from val.

fn dyn_iter<'a>(&'a self) -> Box<dyn Iterator<Item = &'a T> + 'a>

Return an iterator over items in self.

fn as_set(&self) -> &DynSet<T>

Cast any trait object that implements this trait to &DynSet.

This method will not be needed once trait downcasting has been stabilized.

fn as_set_mut(&mut self) -> &mut DynSet<T>

Cast any trait object that implements this trait to &mut DynSet.

This method will not be needed once trait downcasting has been stabilized.

Provided Methods

fn is_empty(&self) -> bool

Check if the set is empty.