pub type DynOpt<T> = dyn Opt<T>;Trait Implementations
Sourceimpl<T> Archive for Box<DynOpt<T>>
impl<T> Archive for Box<DynOpt<T>>
Sourceimpl<T> ArchiveTrait for DynOpt<T>
impl<T> ArchiveTrait for DynOpt<T>
type Archived = dyn DeserializeDyn<dyn Opt<T>>
Sourceimpl<T> DowncastTrait for DynOpt<T>
impl<T> DowncastTrait for DynOpt<T>
Sourcefn downcast_checked<T: AsAny>(&self) -> &T
fn downcast_checked<T: AsAny>(&self) -> &T
Cast trait object reference to a reference to a concrete type
T. Read moreSourcefn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
fn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
Cast trait object reference to a mutable reference to a concrete type
T. Read moreimpl<T> Eq for DynOpt<T>
Sourceimpl<T> PartialOrd for DynOpt<T>
impl<T> PartialOrd for DynOpt<T>
Sourceimpl<T> Serialize<DbspSerializer<'_>> for Box<DynOpt<T>>
impl<T> Serialize<DbspSerializer<'_>> for Box<DynOpt<T>>
Sourcefn serialize(
&self,
_serializer: &mut DbspSerializer<'_>,
) -> Result<Self::Resolver, <DbspSerializer<'_> as Fallible>::Error>
fn serialize( &self, _serializer: &mut DbspSerializer<'_>, ) -> Result<Self::Resolver, <DbspSerializer<'_> as Fallible>::Error>
Writes the dependencies for the object and returns a resolver that can create the archived
type.