pub type DynPairs<T1, T2> = dyn Pairs<T1, T2>;Trait Implementations
Sourceimpl<T1, T2> Archive for Box<DynPairs<T1, T2>>
impl<T1, T2> Archive for Box<DynPairs<T1, T2>>
Sourceimpl<T1, T2> ArchiveTrait for DynPairs<T1, T2>
impl<T1, T2> ArchiveTrait for DynPairs<T1, T2>
type Archived = dyn DeserializeDyn<dyn Pairs<T1, T2>>
Sourceimpl<T1, T2> DowncastTrait for DynPairs<T1, T2>
impl<T1, T2> DowncastTrait for DynPairs<T1, T2>
Sourcefn downcast_checked<T: AsAny>(&self) -> &T
fn downcast_checked<T: AsAny>(&self) -> &T
Cast trait object reference to a reference to a concrete type
T. Read moreSourcefn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
fn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
Cast trait object reference to a mutable reference to a concrete type
T. Read moreimpl<T1, T2> Eq for DynPairs<T1, T2>
Sourceimpl<T1: DataTrait + ?Sized, T2: DataTrait + ?Sized> NumEntries for DynPairs<T1, T2>
impl<T1: DataTrait + ?Sized, T2: DataTrait + ?Sized> NumEntries for DynPairs<T1, T2>
Sourceconst CONST_NUM_ENTRIES: Option<usize> = None
const CONST_NUM_ENTRIES: Option<usize> = None
Returns
Some(n) if Self has constant size or None otherwise.Sourcefn num_entries_shallow(&self) -> usize
fn num_entries_shallow(&self) -> usize
Returns the number of entries in
self.Sourcefn num_entries_deep(&self) -> usize
fn num_entries_deep(&self) -> usize
Recursively computes the number of entries in a container by
calling this method on each entry in
self. Read moreSourceimpl<T1, T2> PartialOrd for DynPairs<T1, T2>
impl<T1, T2> PartialOrd for DynPairs<T1, T2>
Sourceimpl<T1, T2> Serialize<DbspSerializer<'_>> for Box<DynPairs<T1, T2>>
impl<T1, T2> Serialize<DbspSerializer<'_>> for Box<DynPairs<T1, T2>>
Sourcefn serialize(
&self,
_serializer: &mut DbspSerializer<'_>,
) -> Result<Self::Resolver, <DbspSerializer<'_> as Fallible>::Error>
fn serialize( &self, _serializer: &mut DbspSerializer<'_>, ) -> Result<Self::Resolver, <DbspSerializer<'_> as Fallible>::Error>
Writes the dependencies for the object and returns a resolver that can create the archived
type.