pub type DynWeight = dyn Weight;Trait Implementations
Sourceimpl Archive for Box<DynWeight>
impl Archive for Box<DynWeight>
Sourceimpl ArchiveTrait for DynWeight
impl ArchiveTrait for DynWeight
type Archived = dyn DeserializeDyn<dyn Weight>
Sourceimpl DowncastTrait for DynWeight
impl DowncastTrait for DynWeight
Sourcefn downcast_checked<T: AsAny>(&self) -> &T
fn downcast_checked<T: AsAny>(&self) -> &T
Cast trait object reference to a reference to a concrete type
T. Read moreSourcefn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
fn downcast_mut_checked<T: AsAny>(&mut self) -> &mut T
Cast trait object reference to a mutable reference to a concrete type
T. Read moreSourceimpl PartialOrd for DynWeight
impl PartialOrd for DynWeight
Sourcefn serialize(
&self,
_serializer: &mut Serializer,
) -> Result<Self::Resolver, <Serializer as Fallible>::Error>
fn serialize( &self, _serializer: &mut Serializer, ) -> Result<Self::Resolver, <Serializer as Fallible>::Error>
Writes the dependencies for the object and returns a resolver that can create the archived
type.