Module operator

Module operator 

DBSP stream operator implementations.

Operators are implemented in two layers. An outer layer, in most of the submodules of this one, implements a statically typed API. An inner layer, in the dynamic sub-module, is dynamically typed, unsafe, and wrapped by the outer layer in a safe way.

Code that uses DBSP hardly needs to work directly with this module. Instead, use Stream methods to instantiate operators.

Re-exports

pub use dynamic::aggregate::Aggregator;
pub use dynamic::aggregate::Avg;
pub use dynamic::aggregate::Fold;
pub use dynamic::aggregate::Max;
pub use dynamic::aggregate::MaxSemigroup;
pub use dynamic::aggregate::Min;
pub use dynamic::aggregate::MinSemigroup;
pub use dynamic::aggregate::Postprocess;
pub use dynamic::neighborhood::DynNeighborhood;
pub use group::CmpFunc;
pub use input::IndexedZSetHandle;
pub use input::Input;
pub use input::InputHandle;
pub use input::MapHandle;
pub use input::SetHandle;
pub use input::StagedBuffers;
pub use input::Update;
pub use input::ZSetHandle;
pub use dynamic::join_range::StreamJoinRange;
pub use dynamic::neighborhood::NeighborhoodDescr;
pub use dynamic::trace::TraceBound;
pub use neighborhood::NeighborhoodDescrBox;
pub use neighborhood::NeighborhoodDescrStream;
pub use sample::MAX_QUANTILES;
pub use sample::MAX_SAMPLE_SIZE;
pub use time_series::OrdPartitionedIndexedZSet;

Modules

apply2
Binary operator that applies an arbitrary binary function to its inputs.
apply3
Ternary operator that applies an arbitrary ternary function to its inputs.
chain_aggregate
communication
controlled_filter
dynamic
group
input
join
neighborhood
sample
star_join_macros
time_series

Structs

Apply
Operator that applies a user provided function to its input at each timestamp.
Condition
A condition attached to a stream that can be used to terminate the execution of a subcircuit (see ChildCircuit::iterate_with_condition and ChildCircuit::iterate_with_conditions).
ConstantGenerator
A source operator that yields an infinite output stream from a constant value. Note: only worker 0 generates the data; the other workers generate empty streams.
CsvSource
A source operator that reads records of type T from a CSV file.
DelayedFeedback
Like FeedbackConnector but specialized for Z1 feedback operator.
DelayedNestedFeedback
Like FeedbackConnector but specialized for Z1Nested feedback operator.
Delta0
delta_0 DBSP operator.
Generator
A source operator that yields an infinite output stream from a generator function.
GeneratorNested
Generator operator for nested circuits.
Inspect
Sink operator that consumes a stream of values of type T and applies a user-provided callback to each input.
Minus
Operator that computes the difference of values in its two input streams at each timestamp.
OutputHandle
A handle used to read data from a stream from outside the circuit.
Plus
Operator that computes the sum of values in its two input streams at each timestamp.
Sum
Operator that computes the sum of values across all its input streams at each timestamp.
TransactionGenerator
A version of Generator that passes a flag to the generator function when flush has been called, giving it a chance to produce one output per transaction.
TransactionZ1
Z1
z^-1 operator delays its input by one timestamp.
Z1Nested
z^-1 operator over streams of streams.

Traits

RecursiveStreams

Functions

apply_n