Avg

Struct Avg 

pub struct Avg<T, R> { /* private fields */ }
Representation of a partially computed average aggregate as a (sum, count) tuple.

This struct represents the result of the linear part of the average aggregate as a (sum, count) tuple (see Stream::dyn_average). The actual average value can be obtained by dividing sum by count. Avg forms a commutative monoid with point-wise plus operation (sum1, count1) + (sum2, count2) = (sum1 + sum2, count1 + count2).

Implementations

Source

impl<T, R> Avg<T, R>

pub const fn new(sum: T, count: R) -> Self

Create a new Avg object with the given sum and count.

pub fn sum(&self) -> T
where T: Clone,

Returns the sum component of the (sum, count) tuple.

pub fn count(&self) -> R
where R: Clone,

Returns the count component of the (sum, count) tuple.

pub fn compute_avg(&self) -> Option<T>
where R: Clone + HasZero, T: From<R> + Div<Output = T> + Clone,

Returns sum / count or None if count is zero.