Fold

Struct Fold 

pub struct Fold<V, A, S, SF, OF> { /* private fields */ }
An aggregator that can be expressed as a fold of the input Z-set.

The Fold aggregator iterates over (key, weight) pairs with non-zero weights updating the value of an accumulator with a user-provided step function. The final aggregate is produced by applying a user-provided output function to the final value of the accumulator.

Type arguments

  • A - accumulator
  • S - semigroup structure used to compute aggregates piecewise
  • SF - step function
  • OF - output function

Implementations

Source

impl<V, A, S, SF> Fold<V, A, S, SF, fn(A) -> A>

pub fn new(init: A, step: SF) -> Self

Create a Fold aggregator with initial accumulator value init, step function step, and identity output function.

This constructor caters for the common case when the final value of the accumulator is the desired aggregate, i.e., no output processing is required.

Source

impl<V, A, S, SF, OF> Fold<V, A, S, SF, OF>

pub fn with_output(init: A, step: SF, output: OF) -> Self

Create a Fold aggregator with initial accumulator value init, step function step, and output function output.