Module trace

Module trace 

Structs

BoundsId
DelayedTraceId
TraceAppend
TraceBound
Lower bound on keys or values in a trace.
TraceBounds
Data structure that tracks key and value retainment policies for a trace.
TraceFeedbackConnector
See [trait TraceFeedback] documentation.
TraceId
UntimedTraceAppend
Z1Trace

Traits

TraceFeedback
Extension trait to trait Circuit that provides a convenience API to construct circuits of the following shape:

Type Aliases

TimedSpine