Delta0

Struct Delta0 

pub struct Delta0<D> { /* private fields */ }
delta_0 DBSP operator.

delta_0 is an import operator, i.e., an operator that makes the contents of a parent stream available inside the child circuit. At the first nested clock cycle, it reads and outputs a value from the parent stream. During subsequent nested clock cycles, it outputs zero.

Examples

Given a parent stream

[1, 2, 3, 4, ...]

the delta_0 operator produces the following nested stream (each row in the matrix represents a nested clock epoch):

┌           ┐
│1 0 0 0 ...│
│2 0 0 0 ...│
│3 0 0 0 ...|
|4 0 0 0 ...|
└           ┘

Implementations

Source

impl<D> Delta0<D>

pub fn new() -> Self