pub struct TransactionGenerator<T, F> { /* private fields */ }Expand description
A version of Generator that passes a flag to the generator function when flush has been called, giving it a chance
to produce one output per transaction.
Implementations
Sourceimpl<T, F> TransactionGenerator<T, F>
impl<T, F> TransactionGenerator<T, F>