pub struct Z1<T> { /* private fields */ }Expand description
z^-1 operator delays its input by one timestamp.
The operator outputs a user-defined “zero” value in the first timestamp after clock_start. For all subsequent timestamps, it outputs the value received as input at the previous timestamp. The zero value is typically the neutral element of a monoid (e.g., 0 for addition or 1 for multiplication).
It is a strict operator.
Examples
time | input | output
---------------------
0 | 5 | 0
1 | 6 | 5
2 | 7 | 6
3 | 8 | 7
...Implementations