Z1Nested

Struct Z1Nested 

pub struct Z1Nested<T> { /* private fields */ }
z^-1 operator over streams of streams.

The operator stores a complete nested stream consumed at the last iteration of the parent clock and outputs it at the next parent clock cycle. It outputs a stream of zeros in the first parent clock tick.

One important subtlety is that mathematically speaking nested streams are infinite, but we can only compute and store finite prefixes of such streams. When asked to produce output beyond the stored prefix, the z^-1 operator repeats the last value in the stored prefix. The assumption here is that the circuit was evaluated to a fixed point at the previous parent timestamp, and hence the rest of the stream will contain the same fixed point value. This is not generally true for all circuits, and users should keep this in mind when instantiating the operator.

It is a strict operator.

Examples

Input (one row per parent timestamps):

1 2 3 4
1 1 1 1 1
2 2 2 0 0

Output:

0 0 0 0
1 2 3 4 4
1 1 1 1 1