pub trait RecursiveStreams<C>: Clone {
type Inner: DynRecursiveStreams<C> + Clone;
type Output;
// Required methods
unsafe fn typed(inner: &Self::Inner) -> Self;
unsafe fn typed_exports(
inner: &<Self::Inner as DynRecursiveStreams<C>>::Output,
) -> Self::Output;
fn inner(&self) -> Self::Inner;
fn factories() -> <Self::Inner as DynRecursiveStreams<C>>::Factories;
}Required Associated Types
Required Methods
Sourceunsafe fn typed(inner: &Self::Inner) -> Self
unsafe fn typed(inner: &Self::Inner) -> Self
Returns a strongly typed version of the streams.
Safety
inner must be backed by concrete types that match Self.
Sourceunsafe fn typed_exports(
inner: &<Self::Inner as DynRecursiveStreams<C>>::Output,
) -> Self::Output
unsafe fn typed_exports( inner: &<Self::Inner as DynRecursiveStreams<C>>::Output, ) -> Self::Output
Returns a strongly typed version of output streams.
Safety
inner must be backed by concrete types that match Self::Output.
fn inner(&self) -> Self::Inner
fn factories() -> <Self::Inner as DynRecursiveStreams<C>>::Factories
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".