Module storage

Module storage 

Storage APIs for Feldera.

The API consists of a lower layer, backend, that provides block-based access to storage, a middle layer, buffer_cache, that implements buffering, and an upper layer, file, that implements data access.

Modules

backend
Storage backend APIs for Feldera.
buffer_cache
Buffer cache that can be used to cache reads.
dirlock
A simple PID-based locking mechanism.
file
File based data format for Feldera.
tracking_bloom_filter

Functions

init
Performs storage module initialization.