pub struct BlockHeader {
pub checksum: u32,
pub magic: [u8; 4],
}Expand description
8-byte header at the beginning of each block.
A block does not identify its own size, so any reference to a block must also include the block’s size.
Fields
checksum: u3232-bit crc32c checksum of the remainder of the block.
magic: [u8; 4]Magic number. Magic numbers begin with LF, which stands for “layer
file”.