TouchedWindowCount

Struct TouchedWindowCount 

pub struct TouchedWindowCount { /* private fields */ }
Additional metadata added to the file by the writer.

Implementations

Source

impl TouchedWindowCount

pub fn new(count: usize) -> Self

Encodes an exact touched-window count in the range 1..=65_536.

The value 0 is reserved to mean that the exact count is unavailable, or that the batch is empty.

pub fn get(self) -> usize

Returns the stored touched-window count.

The value 0 means the exact count is unavailable.

pub fn is_available(self) -> bool

True if the exact touched-window count is available.