Product

Struct Product 

pub struct Product<TOuter, TInner> {
    pub outer: TOuter,
    pub inner: TInner,
}
A nested pair of timestamps, one outer and one inner.

Fields

outer: TOuter

Outer timestamp.

inner: TInner

Inner timestamp.

Implementations

Source

impl<TOuter, TInner> Product<TOuter, TInner>

pub fn new(outer: TOuter, inner: TInner) -> Product<TOuter, TInner>

Creates a new product from outer and inner coordinates.