ReverseKeyCursor

Struct ReverseKeyCursor 

pub struct ReverseKeyCursor<'a, C: ?Sized, K: ?Sized, V: ?Sized, R: ?Sized> { /* private fields */ }
Cursor that reverses the direction of keys in the underlying cursor.

WARNING: This cursor iterates over keys in descending order, and thus will not work correctly with code that assumes monotonically growing keys.

Implementations

Source

impl<'a, C, K: ?Sized, V: ?Sized, R: ?Sized> ReverseKeyCursor<'a, C, K, V, R>
where C: Cursor<K, V, (), R> + ?Sized,

pub fn new(cursor: &'a mut C) -> Self