GroupFilter

Enum GroupFilter 

pub enum GroupFilter<V: ?Sized + 'static> {
    Simple(Filter<V>),
    LastN(usize, Filter<V>),
    TopN(usize, Filter<V>, &'static dyn Factory<V>),
    BottomN(usize, Filter<V>, &'static dyn Factory<V>),
}
A filter over a group of values associated with a key.

  • Simple - retain all values that satisfy a predicate. Doesn’t make any assumptions about the ordering of values.
  • LastN - retains all values that satisfy a predicate and up to a constant number of values preceding the first value that satisfies the predicate. If no value in the group satisfies the predicate, retains the last N values in the group. Assumes that the predicate is monotonic: once it is satisfied for a value, it is also satisfied for all subsequent values for the same key. Also assumed that the values are ordered in some way, so that the last N values under the cursor ate the ones that need to be preserved.
  • TopN - retains all values that satisfy a predicate and up to a constant number of largest values that do not satisfy the predicate. This is similar to LastN, but it does not assume that the predicate is monotonic.

Note that the LastN, TopN and BottomN filters can not be evaluated against an individual batch and require access to the complete spine that the batch belongs to. The reason is that some of the last N values in the batch may not be present in the trace because there may exist retractions for them in other batches within the spine.

Therefore, these filters are only evaluated as part of a background merge. See BatchReader::merge_batches_with_snapshot for more details.

Variants



Simple(Filter<V>)



LastN(usize, Filter<V>)



TopN(usize, Filter<V>, &'static dyn Factory<V>)



BottomN(usize, Filter<V>, &'static dyn Factory<V>)

Implementations

Source

impl<V: ?Sized + 'static> GroupFilter<V>

pub fn requires_snapshot(&self) -> bool

Returns true if the filter cannot be evaluated against an individual batch and requires access to the complete spine that the batch belongs to.

Source

impl<V: ?Sized> GroupFilter<V>

pub fn metadata(&self) -> MetaItem