LayerBuilder

Struct LayerBuilder 

pub struct LayerBuilder<K, L, O = usize>
where K: DataTrait + ?Sized, L: Builder,
{ pub keys: Box<DynVec<K>>, pub offs: Vec<O>, pub vals: L, /* private fields */ }
Assembles a layer of this

Fields

keys: Box<DynVec<K>>

Keys

offs: Vec<O>

Offsets

vals: L

The next layer down

Implementations

Source

impl<K, L, O> LayerBuilder<K, L, O>
where K: DataTrait + ?Sized, L: Builder,

pub fn merge_step( &mut self, (trie1, lower1, upper1): (&Layer<K, L::Trie, O>, &mut usize, usize), (trie2, lower2, upper2): (&Layer<K, L::Trie, O>, &mut usize, usize), map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, )
where L: MergeBuilder, O: OrdOffset,

Performs one step of merging.

pub fn merge_step_retain_keys<F>( &mut self, (trie1, lower1, upper1): (&<Self as Builder>::Trie, &mut usize, usize), (trie2, lower2, upper2): (&<Self as Builder>::Trie, &mut usize, usize), filter: &F, map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, )
where L: MergeBuilder, O: OrdOffset, F: Fn(&K) -> bool,

Source

impl<K, L, O> LayerBuilder<K, L, O>
where K: DataTrait + ?Sized, L: MergeBuilder, O: OrdOffset,

pub fn push_merge_fueled( &mut self, (source1, lower1, upper1): (&<Self as Builder>::Trie, &mut usize, usize), (source2, lower2, upper2): (&<Self as Builder>::Trie, &mut usize, usize), map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, fuel: &mut isize, )

Like push_merge, but uses fuel to bound the amount of work.

Builds at most fuel values plus values for one extra key. If fuel > 0 when the method returns, this means that the merge is complete.

pub fn push_merge_retain_keys_fueled<F>( &mut self, (source1, lower1, upper1): (&<Self as Builder>::Trie, &mut usize, usize), (source2, lower2, upper2): (&<Self as Builder>::Trie, &mut usize, usize), filter: &F, map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, fuel: &mut isize, )
where F: Fn(&K) -> bool,

pub fn copy_range_fueled( &mut self, other: &<Self as Builder>::Trie, lower: usize, upper: usize, map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, fuel: usize, ) -> usize

Like copy_range, but uses fuel to bound the amount of work.

Invariants:

  • Copies at most fuel values plus values for one extra key.
  • If fuel is greater than or equal to the number of values, in the lower..upper key range, copies the entire range.
Source

impl<K, V, L, O> LayerBuilder<K, L, O>
where K: DataTrait + ?Sized, V: DataTrait + ?Sized, O: OrdOffset, L: MergeBuilder, <L as Builder>::Trie: 'static, for<'a, 'b> <<L as Builder>::Trie as Trie>::Cursor<'a>: Cursor<'a, Key = V>,

pub fn push_merge_retain_values_fueled<KF, VF>( &mut self, (source1, lower1, upper1): (&<Self as Builder>::Trie, &mut usize, usize), (source2, lower2, upper2): (&<Self as Builder>::Trie, &mut usize, usize), key_filter: &KF, value_filter: &VF, map_func: Option<&dyn Fn(&mut <<Self as Builder>::Trie as Trie>::LeafKey)>, fuel: &mut isize, )
where KF: Fn(&K) -> bool, VF: Fn(&V) -> bool,

Like push_merge_fueled, but also removes values that don’t pass filter in both inputs.