TypedBatch

Struct TypedBatch 

pub struct TypedBatch<K, V, R, B> { /* private fields */ }
A statically typed wrapper around a dynamically typed batch B with concrete key, value, and weight types K, V, and R respectively.

Implementations

Source

impl<K, V, R, B> TypedBatch<K, V, R, B>

pub fn new(inner: B) -> Self

Source

impl<K, V, R, B> TypedBatch<K, V, R, B>
where B: DynBatch, K: DBData + Erase<B::Key>, V: DBData + Erase<B::Val>, R: DBWeight + Erase<B::R>,

pub fn empty() -> Self

Create an empty batch.

pub fn from_tuples(time: B::Time, tuples: Vec<Tup2<Tup2<K, V>, R>>) -> Self

Build a batch out of tuples.

pub fn merge(&self, other: &Self) -> Self

Merge self with other.

pub fn merge_batches<I>(batches: I) -> Self
where I: IntoIterator<Item = Self>,

Source

impl<K, V, R, B> TypedBatch<K, V, R, B>

pub fn into_inner(self) -> B

Source

impl<K, R, B> TypedBatch<K, (), R, B>
where B: DynBatch, K: DBData + Erase<B::Key>, (): Erase<B::Val>, R: DBWeight + Erase<B::R>,

pub fn from_keys(time: B::Time, tuples: Vec<Tup2<K, R>>) -> Self

Source

impl<K, V, R, B> TypedBatch<K, V, R, DynSpineSnapshot<B>>
where B: DynBatch, K: DBData + Erase<B::Key>, V: DBData + Erase<B::Val>, R: DBWeight + Erase<B::R>,

pub fn concat<'a, I>(snapshots: I) -> TypedBatch<K, V, R, DynSpineSnapshot<B>>
where I: IntoIterator<Item = &'a Self>,

Concatenate a list of snapshots into a single snapshot.

pub fn consolidate(&self) -> TypedBatch<K, V, R, B>

Consolidate the batches in the snapshot.

Source

impl<K, V, R, B> TypedBatch<K, V, R, B>
where B: DynTrace, K: DBData + Erase<B::Key>, V: DBData + Erase<B::Val>, R: DBWeight + Erase<B::R>,

pub fn consolidate(self) -> TypedBatch<K, V, R, B::Batch>

Consolidate the batches in the trace.

Source

impl<K, V, R, B> TypedBatch<K, V, R, DynSpine<B>>
where B: DynBatch, K: DBData + Erase<B::Key>, V: DBData + Erase<B::Val>, R: DBWeight + Erase<B::R>,

pub fn ro_snapshot(&self) -> TypedBatch<K, V, R, DynSpineSnapshot<B>>