Synchronous circuits over streams.
A circuit consists of operators connected by streams. At every clock cycle, each operator consumes a single value from each of its input streams and emits a single value to the output stream (except that nested circuits can execute multiple operations for each outer clock tick).
Use RootCircuit::build to create and populate an circuit that executes in
the calling thread, or Runtime::init_circuit to create a multi-circuit,
multi-worker threaded runtime. These functions return a CircuitHandle
or DBSPHandle, respectively, that control the circuits’ execution,
plus, when used in the recommended way, additional input handles for
feeding data into the circuits and output handles for obtaining their
output.
Re-exports
pub use circuit_builder::ChildCircuit;pub use circuit_builder::Circuit;pub use circuit_builder::CircuitHandle;pub use circuit_builder::ExportId;pub use circuit_builder::ExportStream;pub use circuit_builder::FeedbackConnector;pub use circuit_builder::GlobalNodeId;pub use circuit_builder::NestedCircuit;pub use circuit_builder::NodeId;pub use circuit_builder::OwnershipPreference;pub use circuit_builder::RootCircuit;pub use circuit_builder::Scope;pub use circuit_builder::Stream;pub use circuit_builder::WithClock;pub use schedule::Error as SchedulerError;
Modules
- cache
- Circuit cache.
- checkpointer
- Logic to manage persistent checkpoints for a circuit.
- circuit_
builder - API to construct circuits.
- metadata
- metrics
- Storage metrics.
- operator_
traits - Common traits for DBSP operators.
- schedule
- The scheduling framework controls the execution of a circuit at runtime.
- tokio
- trace
- Definitions related to tracing the execution of a circuit.
Structs
- Checkpoint
Committer - Committer for a checkpoint.
- Circuit
Config - A config for instantiating a multithreaded/multihost runtime to execute circuits.
- Circuit
Storage Config - Configuration for storage in a Runtime-hosted circuit.
- DBSP
Handle - A handle to control the execution of a circuit in a multithreaded runtime.
- DevTweaks
- Host
- A host for some workers in the
Layoutfor a multi-host DBSP circuit. - Local
Store Marker - Runtime
- A multithreaded runtime that hosts
Ncircuits running in parallel worker threads. Typically, allNcircuits are identical, but this is not required or enforced. - Runtime
Handle - Handle returned by
Runtime::run. - Storage
Config - Configuration for persistent storage in a
PipelineConfig. - Storage
Options - Storage configuration for a pipeline.
- Weak
Runtime - A weak reference to a Runtime.
Enums
- Layout
- How a DBSP circuit is laid out across one or more machines.
- Layout
Error - Mode
- DBSP circuit execution mode.
- Runtime
Error - Storage
Cache Config - How to cache access to storage within a Feldera pipeline.
Functions
- adaptive_
joins_ enabled - balancer_
balance_ tax - balancer_
key_ distribution_ refresh_ threshold - balancer_
min_ absolute_ improvement_ threshold - balancer_
min_ relative_ improvement_ threshold - splitter_
output_ chunk_ size - Returns the chunk size for splitter operators, in records.
Type Aliases
- Local
Store - Local data store shared by all workers in a runtime.