pub struct ExportStream<C, D>where
C: Circuit,{
pub local: Stream<C, D>,
pub export: Stream<C::Parent, D>,
}Expand description
Stream whose final value is exported to the parent circuit.
The struct bundles a pair of streams emitted by a
StrictOperator:
a local stream inside operator’s local circuit and an
export stream available to the parent of the local circuit.
The export stream contains the final value computed by the
operator before clock_end.
Fields
local: Stream<C, D>export: Stream<C::Parent, D>Auto Trait Implementations
impl<C, D> Freeze for ExportStream<C, D>
impl<C, D> !RefUnwindSafe for ExportStream<C, D>
impl<C, D> !Send for ExportStream<C, D>
impl<C, D> !Sync for ExportStream<C, D>
impl<C, D> Unpin for ExportStream<C, D>
impl<C, D> !UnwindSafe for ExportStream<C, D>