pub type Scope = u16;Expand description
Relative location of a circuit in the hierarchy of nested circuits.
0 refers to the local circuit that a given node or operator belongs
to, 1 - to the parent of the local, circuit, 2 - to the parent’s
parent, etc.