pub trait SourceOperator<O>: Operator {
// Required method
async fn eval(&mut self) -> O;
}Expand description
A source operator that injects data from the outside world or from the parent circuit into the local circuit. Consumes no input streams and emits a single output stream.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".