pub struct CircuitConfig {
pub layout: Layout,
pub storage: Option<StorageConfig>,
pub min_storage_bytes: usize,
pub init_checkpoint: Uuid,
}Expand description
A config for instantiating a multithreaded/multihost runtime to execute circuits.
As opposed to RuntimeConfig, this struct stores state about which hosts
run the circuit and where they store data, e.g., state typically not
tunable/exposed by the user.
Fields
layout: LayoutHow the circuit is laid out across one or multiple machines.
storage: Option<StorageConfig>Storage configuration (if storage is enabled).
min_storage_bytes: usizeEstimated minimum number of bytes in a data batch to spill it to
storage. If this is 0, then all batches will be stored on disk; if it is
usize::MAX, then all batches will be kept in memory; and intermediate
values specify a threshold.
init_checkpoint: UuidThe initial checkpoint to start the circuit from.
In case of a new circuit, this should be Uuid::nil().
Setting this to an existing checkpoint will start the circuit from that
and requires that the checkpoint exists in the storage directory.
Implementations
Sourceimpl CircuitConfig
impl CircuitConfig
pub fn with_workers(n: usize) -> Self