pub struct RawVec { /* private fields */ }Implementations
Sourceimpl RawVec
impl RawVec
pub fn new(val_size: usize, align: usize, dangling: *mut u8) -> Self
pub fn with_capacity( val_size: usize, align: usize, capacity: usize, dangling: *mut u8, ) -> Self
Sourcepub unsafe fn from_raw_parts(
ptr: *mut u8,
length: usize,
capacity: usize,
val_size: usize,
align: usize,
) -> Self
pub unsafe fn from_raw_parts( ptr: *mut u8, length: usize, capacity: usize, val_size: usize, align: usize, ) -> Self
Creates a RawVec directly from a pointer, a length, and a capacity.
Safety
ptrmust be a valid pointer tocapacityallocated bytes of whichlengthare validval_sizemust be the size of the elements in the vectoralignmust be the alignment of the elements in the vectorlengthmust be less than or equal tocapacity
pub const fn len(&self) -> usize
pub fn spare_capacity(&self) -> usize
pub fn has_spare_capacity(&self) -> bool
Sourcepub unsafe fn set_len(&mut self, new_len: usize)
pub unsafe fn set_len(&mut self, new_len: usize)
Sets the current vector’s length to new_len
Safety
new_lenmust be less than or equal toself.capacity().- The elements at
old_len..new_lenmust be initialized.
pub const fn is_empty(&self) -> bool
pub const fn capacity(&self) -> usize
pub const fn as_ptr(&self) -> *const u8
pub fn as_mut_ptr(&mut self) -> *mut u8
pub fn reserve(&mut self, additional: usize)
pub fn reserve_exact(&mut self, additional: usize)
pub fn clear(&mut self, drop_slice_in_place: &dyn Fn(*mut u8, usize))
pub fn index(&self, idx: usize) -> *const u8
pub fn index_mut(&mut self, idx: usize) -> *mut u8
Sourcepub unsafe fn index_unchecked(&self, idx: usize) -> *const u8
pub unsafe fn index_unchecked(&self, idx: usize) -> *const u8
Safety
idxmust be less than the length of the vector
Sourcepub unsafe fn index_mut_unchecked(&mut self, idx: usize) -> *mut u8
pub unsafe fn index_mut_unchecked(&mut self, idx: usize) -> *mut u8
Safety
idxmust be less than the length of the vector
pub fn range<R>(&self, range: R) -> (*const u8, usize)where
R: RangeBounds<usize>,
pub fn range_mut<R>(&mut self, range: R) -> (*mut u8, usize)where
R: RangeBounds<usize>,
Sourcepub unsafe fn push_raw(&mut self, value: *const u8)
pub unsafe fn push_raw(&mut self, value: *const u8)
Push a value to the current vector
Safety
value must be a valid pointer to an instance of the current vector’s
type
Sourcepub unsafe fn push_unchecked(&mut self, value: *const u8)
pub unsafe fn push_unchecked(&mut self, value: *const u8)
Safety
valuemust be a valid pointer to an instance of the current vector’s type- the vector must have available capacity greater than zero
Sourcepub unsafe fn append_raw_range(&mut self, start: *const u8, length: usize)
pub unsafe fn append_raw_range(&mut self, start: *const u8, length: usize)
Safety
startmust be a valid pointer to a slice of lengthlengthof the current vector’s type
pub fn eq( &self, other: &Self, eq_func: &dyn Fn(*const u8, *const u8) -> bool, ) -> bool
pub fn cmp( &self, other: &Self, cmp_func: &dyn Fn(*const u8, *const u8) -> Ordering, ) -> Ordering
pub fn hash(&self, hash_func: &mut dyn FnMut(*const u8))
pub fn size_of_children( &self, context: &mut Context, size_of_children_func: &mut dyn Fn(*const u8, &mut Context), )
pub fn debug( &self, f: &mut Formatter<'_>, debug_func: &dyn Fn(*const u8, &mut Formatter<'_>) -> Result, ) -> Result
pub fn dedup_starting_at( &mut self, starting_point: usize, same_bucket: &mut dyn FnMut(*mut u8, *mut u8) -> bool, drop_in_place: &mut dyn FnMut(*mut u8), )
Sourceimpl RawVec
impl RawVec
pub fn shrink_to_fit(&mut self)