Aggregation operators.
Structs
- ArgMin
Some - Given a tuple
Tup1<(Option<K>, V)>, this aggregator that returns the smallest V for the smallest value K that is not None. This is useful for implementing the SQL ARG_MIN operator. Notice that the ARG_MIN(a, b) function returns the smallest a for the smallest b in the collection (it compares first on b); however, the compiler swaps the arguments when using this aggregator, so typeOption<K>below is the type of b, and V is the type of A. (This aggregator is used only when b is nullable, otherwise the regular Min aggregator is fine.) - Avg
- Representation of a partially computed average aggregate as a
(sum, count)tuple. - AvgFactories
- DynAggregator
Impl - Fold
- An aggregator that can be expressed as a fold of the input Z-set.
- IncAggregate
Factories - IncAggregate
Linear Factories - Max
- An aggregator that returns the largest value with non-zero weight.
- MaxSemigroup
- Min
- An aggregator that returns the smallest value with non-zero weight.
- MinSemigroup
- MinSome1
- An aggregator that returns the smallest Some() value with non-zero weight or None if no such value exists.
- MinSome1
Semigroup - Postprocess
- Add postprocessing step to any aggregator.
- Stream
Aggregate Factories - Stream
Linear Aggregate Factories
Traits
- AggCombine
Func - AggOutput
Func - Aggregator
- A trait for aggregator objects. An aggregator summarizes the contents of a Z-set into a single value.
- DynAggregator
- Weighted
Count OutFunc