pub struct Avg<T, R> { /* private fields */ }Expand description
Representation of a partially computed average aggregate as a (sum, count)
tuple.
This struct represents the result of the linear part of the average
aggregate as a (sum, count) tuple (see Stream::dyn_average). The
actual average value can be obtained by dividing sum by count. Avg
forms a commutative monoid with point-wise plus operation (sum1, count1) + (sum2, count2) = (sum1 + sum2, count1 + count2).
Implementations