pub struct ReverseKeyCursor<'a, C: ?Sized, K: ?Sized, V: ?Sized, R: ?Sized> { /* private fields */ }Expand description
Cursor that reverses the direction of keys in the underlying cursor.
WARNING: This cursor iterates over keys in descending order, and thus will not work correctly with code that assumes monotonically growing keys.
Implementations