pub struct Spine<B>where
B: Batch,{ /* private fields */ }Expand description
Persistence optimized trace implementation based on collection and merging immutable batches of updates.
This spine works asynchronously. The batches exposed to cursors are maintained separately from the batches currently being merged by an asynchronous thread. When one or more merges complete, the spine fetches the new (smaller) collection of batches from the thread in the next step. (It could fetch them earlier, but it might be unfriendly to expose potentially one form of data to a given cursor and then a different form to the next one within a single step.)
Implementations
Sourceimpl<B> Spine<B>where
B: Batch,
impl<B> Spine<B>where
B: Batch,
Sourcepub fn with_runtime(
runtime: Runtime,
worker_index: usize,
factories: &B::Factories,
name: Arc<String>,
) -> Self
pub fn with_runtime( runtime: Runtime, worker_index: usize, factories: &B::Factories, name: Arc<String>, ) -> Self
Allocates a new Spine for worker_index in runtime.
In the common case, Spine::new uses the current thread’s runtime and worker index.
pub fn complete_merges(&mut self)
Sourcepub fn maybe_flush_batch<F>(
batch: impl Into<Arc<B>>,
factories: &B::Factories,
filters: F,
) -> Arc<B> ⓘ
pub fn maybe_flush_batch<F>( batch: impl Into<Arc<B>>, factories: &B::Factories, filters: F, ) -> Arc<B> ⓘ
Returns batch, first pushing it to storage if it exceeds the
user-configured min_storage_bytes or if we’re under high memory
pressure.
Sourcepub fn backpressure_waiter(&self) -> Option<OwnedNotified>
pub fn backpressure_waiter(&self) -> Option<OwnedNotified>
Returns an object that can be used to wait for backpressure to be
relieved. Returns None if no backpressure is needed.