pub struct Spine<B>where
B: Batch,{ /* private fields */ }Expand description
Persistence optimized trace implementation based on collection and merging immutable batches of updates.
This spine works asynchronously. The batches exposed to cursors are maintained separately from the batches currently being merged by an asynchronous thread. When one or more merges complete, the spine fetches the new (smaller) collection of batches from the thread in the next step. (It could fetch them earlier, but it might be unfriendly to expose potentially one form of data to a given cursor and then a different form to the next one within a single step.)
Implementations
Sourceimpl<B> Spine<B>where
B: Batch,
impl<B> Spine<B>where
B: Batch,
Sourcepub fn with_effort(factories: &B::Factories, _effort: usize) -> Self
pub fn with_effort(factories: &B::Factories, _effort: usize) -> Self
Allocates a fueled Spine with a specified effort multiplier.
This trace will merge batches progressively, with each inserted batch
applying a multiple of the batch’s length in effort to each merge.
The effort parameter is that multiplier. This value should be at
least one for the merging to happen; a value of zero is not helpful.
pub fn complete_merges(&mut self)