pub struct TypedBatch<K, V, R, B> { /* private fields */ }Expand description
A statically typed wrapper around a dynamically typed batch B with concrete key, value, and
weight types K, V, and R respectively.
Implementations
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, B>
impl<K, V, R, B> TypedBatch<K, V, R, B>
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, B>
impl<K, V, R, B> TypedBatch<K, V, R, B>
Sourcepub fn from_tuples(time: B::Time, tuples: Vec<Tup2<Tup2<K, V>, R>>) -> Self
pub fn from_tuples(time: B::Time, tuples: Vec<Tup2<Tup2<K, V>, R>>) -> Self
Build a batch out of tuples.
pub fn merge_batches<I>(batches: I) -> Selfwhere
I: IntoIterator<Item = Self>,
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, B>
impl<K, V, R, B> TypedBatch<K, V, R, B>
pub fn into_inner(self) -> B
Sourceimpl<K, R, B> TypedBatch<K, (), R, B>
impl<K, R, B> TypedBatch<K, (), R, B>
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, DynSpineSnapshot<B>>
impl<K, V, R, B> TypedBatch<K, V, R, DynSpineSnapshot<B>>
Sourcepub fn concat<'a, I>(snapshots: I) -> TypedBatch<K, V, R, DynSpineSnapshot<B>>where
I: IntoIterator<Item = &'a Self>,
pub fn concat<'a, I>(snapshots: I) -> TypedBatch<K, V, R, DynSpineSnapshot<B>>where
I: IntoIterator<Item = &'a Self>,
Concatenate a list of snapshots into a single snapshot.
Sourcepub fn consolidate(&self) -> TypedBatch<K, V, R, B>
pub fn consolidate(&self) -> TypedBatch<K, V, R, B>
Consolidate the batches in the snapshot.
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, B>
impl<K, V, R, B> TypedBatch<K, V, R, B>
Sourcepub fn consolidate(self) -> TypedBatch<K, V, R, B::Batch>
pub fn consolidate(self) -> TypedBatch<K, V, R, B::Batch>
Consolidate the batches in the trace.
Sourceimpl<K, V, R, B> TypedBatch<K, V, R, DynSpine<B>>
impl<K, V, R, B> TypedBatch<K, V, R, DynSpine<B>>
pub fn ro_snapshot(&self) -> TypedBatch<K, V, R, DynSpineSnapshot<B>>